@@ -15,8 +15,10 @@
 # limitations under the License.
 #
 
+import warnings
 from ai.h2o.sparkling.SharedBackendConfUtils import SharedBackendConfUtils
 
+
 class InternalBackendConf(SharedBackendConfUtils):
 
     #
@@ -26,6 +28,9 @@ class InternalBackendConf(SharedBackendConfUtils):
     def numH2OWorkers(self):
         return self._get_option(self._jconf.numH2OWorkers())
 
+    def extraClusterNodes(self):
+        return self._jconf.extraClusterNodes()
+
     def drddMulFactor(self):
         return self._jconf.drddMulFactor()
 
@@ -38,47 +43,60 @@ class InternalBackendConf(SharedBackendConfUtils):
     def subseqTries(self):
         return self._jconf.subseqTries()
 
-    def nodeIcedDir(self):
-        return self._get_option(self._jconf.nodeIcedDir())
-
     def hdfsConf(self):
         return self._get_option(self._jconf.hdfsConf())
 
     def spreadRddRetriesTimeout(self):
         return self._jconf.spreadRddRetriesTimeout()
 
+    def isDirectIpConfigurationEnabled(self):
+        return self._jconf.isDirectIpConfigurationEnabled()
+
+
     #
     # Setters
     #
 
-    def setNumH2OWorkers(self, numWorkers):
-        self._jconf.setNumH2OWorkers(numWorkers)
+    def setNumH2OWorkers(self, value):
+        self._jconf.setNumH2OWorkers(value)
         return self
 
-    def setDrddMulFactor(self, factor):
-        self._jconf.setDrddMulFactor(factor)
+    def setExtraClusterNodesEnabled(self):
+        self._jconf.setExtraClusterNodesEnabled()
         return self
 
-    def setNumRddRetries(self, retries):
-        self._jconf.setNumRddRetries(retries)
+    def setExtraClusterNodesDisabled(self):
+        self._jconf.setExtraClusterNodesDisabled()
         return self
 
-    def setDefaultCloudSize(self, defaultClusterSize):
-        self._jconf.setDefaultCloudSize(defaultClusterSize)
+    def setDrddMulFactor(self, value):
+        self._jconf.setDrddMulFactor(value)
         return self
 
-    def setSubseqTries(self, subseqTriesNum):
-        self._jconf.setSubseqTries(subseqTriesNum)
+    def setNumRddRetries(self, value):
+        self._jconf.setNumRddRetries(value)
         return self
 
-    def setNodeIcedDir(self, dir):
-        self._jconf.setNodeIcedDir(dir)
+    def setDefaultCloudSize(self, value):
+        self._jconf.setDefaultCloudSize(value)
         return self
 
-    def setHdfsConf(self, hdfsConf):
-        self._jconf.setHdfsConf(hdfsConf)
+    def setSubseqTries(self, value):
+        self._jconf.setSubseqTries(value)
         return self
 
-    def setSpreadRddRetriesTimeout(self, timeout):
-        self._jconf.setSpreadRddRetriesTimeout(timeout)
+    def setHdfsConf(self, value):
+        self._jconf.setHdfsConf(value)
+        return self
+
+    def setSpreadRddRetriesTimeout(self, value):
+        self._jconf.setSpreadRddRetriesTimeout(value)
+        return self
+
+    def setDirectIpConfigurationEnabled(self):
+        self._jconf.setDirectIpConfigurationEnabled()
+        return self
+
+    def setDirectIpConfigurationDisabled(self):
+        self._jconf.setDirectIpConfigurationDisabled()
         return self
