@@ -16,7 +16,7 @@
 #
 
 from ai.h2o.sparkling.ml.algos import H2OKMeans, H2OAutoML, H2OGridSearch, H2OGLM, H2OGAM, H2OGBM, H2OXGBoost
-from ai.h2o.sparkling.ml.algos import H2ODeepLearning, H2ODRF, H2OIsolationForest, H2OCoxPH, H2ORuleFit
+from ai.h2o.sparkling.ml.algos import H2ODeepLearning, H2ODRF, H2OIsolationForest, H2OCoxPH, H2ORuleFit, H2OStackedEnsemble
 from ai.h2o.sparkling.ml.algos.classification import H2OAutoMLClassifier, H2OGLMClassifier, H2OGAMClassifier, H2OGBMClassifier
 from ai.h2o.sparkling.ml.algos.classification import H2OXGBoostClassifier, H2ODeepLearningClassifier, H2ODRFClassifier, H2ORuleFitClassifier
 from ai.h2o.sparkling.ml.algos.regression import H2OAutoMLRegressor, H2OGLMRegressor, H2OGAMRegressor, H2OGBMRegressor
@@ -24,6 +24,6 @@ from ai.h2o.sparkling.ml.algos.regression import H2OXGBoostRegressor, H2ODeepLea
 from ai.h2o.sparkling.ml.features import H2OTargetEncoder, ColumnPruner, H2OWord2Vec, H2OAutoEncoder, H2OPCA, H2OGLRM
 from ai.h2o.sparkling.ml.models import H2OSupervisedMOJOModel, H2OTreeBasedSupervisedMOJOModel, H2OUnsupervisedMOJOModel, H2OTreeBasedUnsupervisedMOJOModel, H2OBinaryModel
 from ai.h2o.sparkling.ml.models import H2OKMeansMOJOModel, H2OGLMMOJOModel, H2OGAMMOJOModel, H2OGBMMOJOModel, H2OXGBoostMOJOModel
-from ai.h2o.sparkling.ml.models import H2ODeepLearningMOJOModel, H2OAutoEncoderMOJOModel, H2ODRFMOJOModel, H2OPCAMOJOModel, H2OGLRMMOJOModel
-from ai.h2o.sparkling.ml.models import H2OIsolationForestMOJOModel, H2OCoxPHMOJOModel, H2ORuleFitMOJOModel
+from ai.h2o.sparkling.ml.models import H2ODeepLearningMOJOModel, H2OWord2VecMOJOModel, H2OAutoEncoderMOJOModel, H2ODRFMOJOModel, H2OPCAMOJOModel, H2OGLRMMOJOModel
+from ai.h2o.sparkling.ml.models import H2OIsolationForestMOJOModel, H2OCoxPHMOJOModel, H2ORuleFitMOJOModel, H2OStackedEnsembleMOJOModel
 from ai.h2o.sparkling.ml.models import H2OMOJOModel, H2OAlgorithmMOJOModel, H2OFeatureMOJOModel, H2OMOJOPipelineModel, H2OMOJOSettings
