@@ -15,7 +15,6 @@
 # limitations under the License.
 #
 
-from h2o.utils.typechecks import assert_is_type
 from pyspark.ml.param import *
 from pyspark.ml.wrapper import JavaWrapper
 
@@ -25,21 +24,24 @@ class H2OMOJOSettings(JavaWrapper):
     def __init__(self,
                  predictionCol="prediction",
                  detailedPredictionCol="detailed_prediction",
-                 withDetailedPredictionCol=True,
                  convertUnknownCategoricalLevelsToNa=False,
                  convertInvalidNumbersToNa=False,
                  namedMojoOutputColumns=True,
                  withContributions=False,
-                 withLeafNodeAssignments=False):
+                 withLeafNodeAssignments=False,
+                 withStageResults=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer"):
         self._java_obj = None
 
-        assert_is_type(predictionCol, str)
-        assert_is_type(detailedPredictionCol, str)
-        assert_is_type(convertUnknownCategoricalLevelsToNa, bool)
-        assert_is_type(convertInvalidNumbersToNa, bool)
-        assert_is_type(namedMojoOutputColumns, bool)
-        assert_is_type(withContributions, bool)
-        assert_is_type(withLeafNodeAssignments, bool)
+        assert isinstance(predictionCol, str)
+        assert isinstance(detailedPredictionCol, str)
+        assert isinstance(convertUnknownCategoricalLevelsToNa, bool)
+        assert isinstance(convertInvalidNumbersToNa, bool)
+        assert isinstance(namedMojoOutputColumns, bool)
+        assert isinstance(withContributions, bool)
+        assert isinstance(withLeafNodeAssignments, bool)
+        assert isinstance(withStageResults, bool)
+        assert isinstance(dataFrameSerializer, str)
         self.predictionCol = predictionCol
         self.detailedPredictionCol = detailedPredictionCol
         self.convertUnknownCategoricalLevelsToNa = convertUnknownCategoricalLevelsToNa
@@ -47,17 +49,20 @@ class H2OMOJOSettings(JavaWrapper):
         self.namedMojoOutputColumns = namedMojoOutputColumns
         self.withContributions = withContributions
         self.withLeafNodeAssignments = withLeafNodeAssignments
+        self.withStageResults = withStageResults
+        self.dataFrameSerializer = dataFrameSerializer
 
     def toJavaObject(self):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.models.H2OMOJOSettings",
                                             self.predictionCol,
                                             self.detailedPredictionCol,
-                                            True,
                                             self.convertUnknownCategoricalLevelsToNa,
                                             self.convertInvalidNumbersToNa,
                                             self.namedMojoOutputColumns,
                                             self.withContributions,
-                                            self.withLeafNodeAssignments)
+                                            self.withLeafNodeAssignments,
+                                            self.withStageResults,
+                                            self.dataFrameSerializer)
         return self._java_obj
 
     @staticmethod
