@@ -1,4 +1,6 @@
 # -*- encoding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import functools as ft
 from inspect import getdoc
 import re
@@ -9,6 +11,7 @@ from h2o.estimators import H2OEstimator
 from h2o.exceptions import H2OResponseError, H2OValueError
 from h2o.frame import H2OFrame
 from h2o.job import H2OJob
+from h2o.utils.compatibility import *  # NOQA
 from h2o.utils.shared_utils import check_id
 from h2o.utils.typechecks import assert_is_type, is_type, numeric
 from ._base import H2OAutoMLBaseMixin, _fetch_state
@@ -131,6 +134,7 @@ class H2OAutoML(H2OAutoMLBaseMixin, Keyed):
                  max_runtime_secs=None,
                  max_runtime_secs_per_model=None,
                  max_models=None,
+                 distribution="AUTO",
                  stopping_metric="AUTO",
                  stopping_tolerance=None,
                  stopping_rounds=3,
@@ -166,12 +170,20 @@ class H2OAutoML(H2OAutoMLBaseMixin, Keyed):
             Requires ``balance_classes``.
             Defaults to ``5.0``.
         :param int max_runtime_secs: Specify the maximum time that the AutoML process will run for.
-            If neither ``max_runtime_secs`` nor ``max_models`` are specified by the user, then ``max_runtime_secs`` dynamically
+            If both ``max_runtime_secs`` and ``max_models`` are specified, then the AutoML run will stop as soon as it hits either of these limits.
+            If neither ``max_runtime_secs`` nor ``max_models`` are specified, then ``max_runtime_secs`` dynamically
             defaults to 3600 seconds (1 hour). Otherwise, defaults to ``0`` (no limit).
         :param int max_runtime_secs_per_model: Controls the max time the AutoML run will dedicate to each individual model.
             Defaults to ``0`` (disabled: no time limit).
+            Note that models constrained by a time budget are not guaranteed reproducible.
         :param int max_models: Specify the maximum number of models to build in an AutoML run, excluding the Stacked Ensemble models.
             Defaults to ``None`` (disabled: no limitation).
+            Always set this parameter to ensure AutoML reproducibility: all models are then trained until convergence and none is constrained by a time budget.
+        :param Union[str, dict] distribution: Distribution function used by algorithms that support it; other algorithms
+            use their defaults.  Possible values: "AUTO", "bernoulli", "multinomial", "gaussian", "poisson", "gamma",
+            "tweedie", "laplace", "quantile", "huber", "custom", and for parameterized distributions dictionary form is
+            used to specify the parameter, e.g., ``dict(type="tweedie", tweedie_power=1.5)``.
+            Defaults to ``AUTO``.
         :param str stopping_metric: Specifies the metric to use for early stopping. 
             The available options are:
             ``"AUTO"`` (This defaults to ``"logloss"`` for classification, ``"deviance"`` for regression),
@@ -284,6 +296,7 @@ class H2OAutoML(H2OAutoMLBaseMixin, Keyed):
 
         self.project_name = project_name
         self.nfolds = nfolds
+        self.distribution = distribution
         self.balance_classes = balance_classes
         self.class_sampling_factors = class_sampling_factors
         self.max_after_balance_size = max_after_balance_size
@@ -332,7 +345,7 @@ class H2OAutoML(H2OAutoMLBaseMixin, Keyed):
         if modeling_plan is None:
             return None
 
-        supported_aliases = ['all', 'defaults', 'grids']
+        supported_aliases = PList(['all', 'defaults', 'grids'])
 
         def assert_is_step_def(sd):
             assert 'name' in sd, "each definition must have a 'name' key"
@@ -401,11 +414,45 @@ class H2OAutoML(H2OAutoMLBaseMixin, Keyed):
     def __validate_frame(self, fr, name=None, required=False):
         return H2OFrame._validate(fr, name, required=required)
 
+    def __validate_distribution(self, distribution):
+        if is_type(distribution, str):
+            distribution = distribution.lower()
+            if distribution == "custom":
+                raise H2OValueError('Distribution "custom" has to be specified as a '
+                                    'dictionary with their respective parameters, e.g., '
+                                    '`dict(type = \"custom\", custom_distribution_func = \"...\"))`.')
+            return distribution
+        if is_type(distribution, dict):
+            dist = distribution["type"].lower()
+            allowed_distribution_parameters = dict(
+                custom='custom_distribution_func',
+                huber='huber_alpha',
+                quantile='quantile_alpha',
+                tweedie='tweedie_power'
+            )
+            assert distribution.get(allowed_distribution_parameters.get(dist)) is not None or len(distribution) == 1, (
+                    "Distribution dictionary should contain distribution and a distribution "
+                    "parameter. For example `dict(type=\"{}\", {}=...)`."
+            ).format(dist, allowed_distribution_parameters[dist])
+            if distribution["type"] == "custom" and "custom_distribution_func" not in distribution.keys():
+                raise H2OValueError('Distribution "custom" has to be specified as a '
+                            'dictionary with their respective parameters, e.g., '
+                            '`dict(type = \"custom\", custom_distribution_func = \"...\"))`.')
+            if allowed_distribution_parameters.get(dist) in distribution.keys():
+                setattr(self, "_"+allowed_distribution_parameters[dist], distribution[allowed_distribution_parameters[dist]])
+            return dist
+
+
     _extract_params_doc(getdoc(__init__))
     project_name = _aml_property('build_control.project_name', types=(None, str), freezable=True,
                                  validate_fn=__validate_project_name)
     nfolds = _aml_property('build_control.nfolds', types=(int,), freezable=True,
                            validate_fn=__validate_nfolds)
+    distribution = _aml_property('build_control.distribution', types=(str, dict), freezable=True, validate_fn=__validate_distribution)
+    _custom_distribution_func = _aml_property('build_control.custom_distribution_func', types=(str,), freezable=True)
+    _huber_alpha = _aml_property('build_control.huber_alpha', types=(numeric,), freezable=True)
+    _tweedie_power = _aml_property('build_control.tweedie_power', types=(numeric,), freezable=True)
+    _quantile_alpha = _aml_property('build_control.quantile_alpha', types=(numeric,), freezable=True)
     balance_classes = _aml_property('build_control.balance_classes', types=(bool,), freezable=True)
     class_sampling_factors = _aml_property('build_control.class_sampling_factors', types=(None, [numeric]), freezable=True)
     max_after_balance_size = _aml_property('build_control.max_after_balance_size', types=(None, numeric), freezable=True)
@@ -642,7 +689,6 @@ class H2OAutoML(H2OAutoMLBaseMixin, Keyed):
         levels = ['debug', 'info', 'warn', 'error']
         if verbosity is None or verbosity.lower() not in levels:
             return
-
         try:
             if job.progress > state.get('last_job_progress', 0):
                 events_table = _fetch_state(job.dest_key, properties=[], verbosity=verbosity)['json']['event_log_table']
